# -*- coding: utf-8 -*-
# Generated by Django 1.10.8 on 2018-04-09 13:01
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('Users', '0002_custommenuitem_reverse_kwargs'),
    ]

    operations = [
        migrations.AlterField(
            model_name='custommenu',
            name='icon',
            field=models.CharField(blank=True, default='', max_length=20, verbose_name='icon'),
        ),
        migrations.AlterField(
            model_name='custommenuitem',
            name='attributes',
            field=models.CharField(blank=True, default='', max_length=100, verbose_name='attributes'),
        ),
        migrations.AlterField(
            model_name='custommenuitem',
            name='icon',
            field=models.CharField(blank=True, default='', max_length=20, verbose_name='icon'),
        ),
        migrations.AlterField(
            model_name='custommenuitem',
            name='reverse',
            field=models.CharField(blank=True, default='', max_length=100, verbose_name='reverse'),
        ),
        migrations.AlterField(
            model_name='custommenuitem',
            name='reverse_kwargs',
            field=models.CharField(blank=True, default='', help_text='kwargs to use for building the reverse. kw1:defaultval1,kw2,kw3:defaultval3 ', max_length=100, verbose_name='reverse_kwargs'),
        ),
        migrations.AlterField(
            model_name='custommenuitem',
            name='url',
            field=models.CharField(blank=True, default='', max_length=100, verbose_name='url'),
        ),
    ]
