{% extends "Emailing/public/base_custom.html" %}
{% load i18n %}
{% block custom_content %}
    <h1>{% trans "Your email has been verified." %}</h1>
    <p>
    {% blocktrans %}
    Thanks for subscribing to the {{my_company}} mailing-list.
    {% endblocktrans %}
    </p>
{% endblock %}
