# -*- coding: utf-8 -*-
# Generated by Django 1.11.14 on 2018-07-09 13:52
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('Crm', '0024_actionstatus_next_on_send'),
    ]

    operations = [
        migrations.AddField(
            model_name='actionstatus',
            name='allowed_on_frozen',
            field=models.BooleanField(default=True, help_text='If False, not shown if action si frozen', verbose_name='allowed on frozen'),
        ),
    ]
