{% extends template_base %}
{% load i18n %}

{% block extra_title %}{{ entity.name }} {% endblock %}

{% block document_content %}
  
{% include "Crm/_section_entity_info.html" with groups=entity.group_set %}

{% include "Crm/_section_contacts.html" %}

{% if not preview %}

  {% include "Crm/_section_actions_by_set.html" %}
{% endif %}

{% endblock %}
