{% extends "coop_cms/newsletter_base.html" %}
{% load i18n emailing_utils %}

{% block email_only_header %}
<div class="top-header email-only" {% include "Emailing/_linkbar_style.html" %}>
    {% if contact and emailing %}
    <div class="item">
    {% trans "If you can't view this email, " %}
    <a {% include "Emailing/_linkbar_link_style.html" %} href="{% url "emailing_view_online" emailing.id contact.uuid %}">
        {% trans "read the online version" %}
    </a>
    </div>
    <div class="top-header-item">
        {% blocktrans %}
        You receive this email because you subscribe to our mailing list. {{my_company}}.
        You can unsubscribe by clicking 
        {% endblocktrans %}
        <a {% include "Emailing/_linkbar_link_style.html" %} href="{% url "emailing_unregister" emailing.id contact.uuid %}">
            {% trans "this link" %}
        </a>
    </div>
    {% endif %}
</div>
{% endblock %}

{% block email_only_footer %}
    {% if contact and emailing %}
<div class="bottom-footer email-only" {% include "Emailing/_linkbar_style.html" %}>
    <div class="item">
        {% blocktrans %}
        You receive this email because you subscribe to our mailing list. {{my_company}}.
        You can unsubscribe by clicking 
        {% endblocktrans %}
        <a {% include "Emailing/_linkbar_link_style.html" %} href="{% url "emailing_unregister" emailing.id contact.uuid %}">
            {% trans "this link" %}
        </a>
    </div>
    {% endif %}
{% endblock %}

{% block email_only_tracking %}
    {% email_tracking %}
{% endblock %}
