# -*- coding: utf-8 -*-
# Generated by Django 1.11.20 on 2019-04-04 15:25
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('Crm', '0027_auto_20190328_1336'),
    ]

    operations = [
        migrations.CreateModel(
            name='CustomFieldChoice',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('value', models.CharField(max_length=100, verbose_name='value')),
                ('label', models.CharField(max_length=100, verbose_name='label')),
                ('order', models.IntegerField(default=0, verbose_name='order')),
            ],
            options={
                'verbose_name': 'custom field choice',
                'verbose_name_plural': 'custom field choices',
                'ordering': ('order', 'label'),
            },
        ),
        migrations.AddField(
            model_name='customfield',
            name='choices',
            field=models.ManyToManyField(blank=True, to='Crm.CustomFieldChoice'),
        ),
    ]
