# -*- coding: utf-8 -*-
# Generated by Django 1.11.20 on 2019-05-09 22:52
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('sites', '0002_alter_domain_unique'),
        ('Crm', '0028_auto_20190404_1525'),
    ]

    operations = [
        migrations.AddField(
            model_name='subscriptiontype',
            name='allowed_on_sites',
            field=models.ManyToManyField(blank=True, related_name='_subscriptiontype_allowed_on_sites_+', to='sites.Site'),
        ),
    ]
