# -*- coding: utf-8 -*-
# Generated by Django 1.11.14 on 2018-07-09 11:49
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('Crm', '0022_auto_20180706_1344'),
    ]

    operations = [
        migrations.AddField(
            model_name='action',
            name='frozen',
            field=models.BooleanField(default=False, help_text='Some data (date, sale, ...) can not be changed ', verbose_name='frozen'),
        ),
    ]
