# -*- coding: utf-8 -*-
# Generated by Django 1.11.14 on 2018-07-25 09:05
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('Store', '0015_storemanagementactiontype_default_readonly_status'),
    ]

    operations = [
        migrations.AddField(
            model_name='storeitem',
            name='item_accounting_code',
            field=models.CharField(blank=True, default='', max_length=20, verbose_name='accounting code'),
        ),
        migrations.AddField(
            model_name='storeitemcategory',
            name='accounting_code',
            field=models.CharField(blank=True, default='', max_length=20, verbose_name='accounting code'),
        ),
    ]
