<!DOCYTPE HTML>{% load i18n %}
<html>
<head>
  <meta charset="utf-8">
  <meta http-equiv="Content-Type" content="text/html;charset=utf-8" />
  <meta http-equiv="X-UA-Compatible" content="IE=edge,chrome=1">
  <meta name="viewport" content="width=device-width, initial-scale=1.0">
  <link rel="shortcut icon" href="{{ STATIC_URL }}img/favicon.png">
  <title>Balafon - {% block extra_title %}{% trans "Contact management" %} {% endblock %}</title>
	
  {% block jquery_declaration %}
	{{jhouston}}
    <link type="text/css" href="{{ STATIC_URL }}css/base/jquery-ui-1.9.2.css" rel="Stylesheet" />	
    <link type="text/css" href="{{ STATIC_URL }}css/colorbox.css?v={{BALAFON_VERSION}}" rel="Stylesheet" />
    <script type="text/javascript" charset="utf-8" src="{{ STATIC_URL }}js/jquery-1.11.3.js"></script>
    <script type="text/javascript" src="{{ STATIC_URL }}js/jquery-ui-1.9.2.js"></script>
    <script type="text/javascript" src="{{ STATIC_URL }}js/jquery-ajax-csrf.js?v={{BALAFON_VERSION}}"></script>
    <script type="text/javascript" src="{{ STATIC_URL }}js/jquery.colorbox-min.js?v={{BALAFON_VERSION}}"></script>
    <script type="text/javascript" src="{{ STATIC_URL }}js/jquery.form.js?v={{BALAFON_VERSION}}"></script>
    <script type="text/javascript" src="{{ STATIC_URL }}js/colorbox.coop.js?v={{BALAFON_VERSION}}"></script>
    <script type="text/javascript">
      $(function () {
        $("a.colorbox-form").colorboxify();
      });
    </script>
  {% endblock %}
  <script type="text/javascript" charset="utf-8" src="{{ STATIC_URL }}js/modernizr.js?v={{BALAFON_VERSION}}"></script>
  
	<script src="{{STATIC_URL}}bs/js/bootstrap.min.js?v={{BALAFON_VERSION}}"></script>
	<script src="{{STATIC_URL}}js/balafon.js?v={{BALAFON_VERSION}}"></script>

    <script type="text/javascript">
    $(function () {
      $('[data-toggle="tooltip"]').tooltip();
    })
    </script>
	
    <!-- Bootstrap core CSS -->
    <link rel="stylesheet" href="{{ STATIC_URL }}css/normalize.css" type="text/css" />
    <link href="{{STATIC_URL}}bs/css/bootstrap.css" rel="stylesheet">
    <link type="text/css" href="{{ STATIC_URL }}chosen/chosen-bootstrap.css" rel="Stylesheet" />
    <link type="text/css" href="{{ STATIC_URL }}css/coop_cms.css" rel="Stylesheet" />
	<link rel="stylesheet" href="{{ STATIC_URL }}css/balafon.css?v={{BALAFON_VERSION}}" type="text/css" />
	
    <!-- HTML5 shim and Respond.js IE8 support of HTML5 elements and media queries -->
    <!--[if lt IE 9]>
      <script src="{{STATIC_URL}}js/html5shiv.js"></script>
      <script src="{{STATIC_URL}}js/respond.min.js"></script>
    <![endif]-->
    <link href='https://fonts.googleapis.com/css?family=Source+Sans+Pro:400' rel='stylesheet' type='text/css'>
	<link href='https://fonts.googleapis.com/css?family=Fenix' rel='stylesheet' type='text/css'>
    {% block extra_head %}{% endblock %}
</head>
<body>
  <noscript>
    <div class="noscript">{% trans "This application requires javascript to be enabled" %}</div>
  </noscript>
  {% block header_bar %}
  {% include "balafon/_bs_navigation.html" %}
  {% endblock %}
  <div class="container {% if not preview %}container-not-preview{% endif %}">
  {% block main %}
    {% include "coop_cms/_messages.html" %}
    
    {% block document %}
    <div id="document">
      <div class="row">
        <div class="col-md-12">
          <div class="version pull-right">Balafon {{ BALAFON_VERSION }}</div>
        </div>
      </div>
      <div class="letter-bar" rel="{% url 'crm_view_entities_list' %}">
        <label>{% trans "Contacts" %}</label>
      {% for l in "*ABCDEFGHIJKLMNOPQRSTUVWXYZ~" %}
        <span class="letter-filter btn btn-xs {% if letter_filter == l %}btn-primary{% else %}btn-default{% endif %}" rel="{{l}}">
          {{l}}
        </span>
      {% endfor %}
      </div>
      <h2>{% block document_title %}{{document_title}}{% endblock %}</h2>
      {% block document_content %}{% endblock %}
    {% endblock %}
    </div>
    
    {% block footer %}
    {% endblock %}

  {% endblock %}
  </div>
</body>
</html>