{% extends "balafon/bs_base.html" %}
{% load i18n %}
{% block extra_title %}{% trans "Emailing list" %}{% endblock %}

{% block document_title %}{% endblock %}
{% block document_content %}
    
{% include "Emailing/_section_newsletters.html" %}

{% endblock %}